@@ -29,7 +29,7 @@ class dvdauthor_converter(devedeng.executor.executor):
         self.config = devedeng.configuration_data.configuration.get_config()
 
 
-    def create_dvd_project (self, path, name, file_movies, menu_entries, start_with_menu):
+    def create_dvd_project (self, path, name, file_movies, menu_entries, start_with_menu, play_all_opt):
 
         movie_path = os.path.join(path,"dvd_tree")
         try:
@@ -37,7 +37,7 @@ class dvdauthor_converter(devedeng.executor.executor):
         except:
             pass
 
-        xml_file = self.create_dvdauthor_xml(path, file_movies, menu_entries, start_with_menu)
+        xml_file = self.create_dvdauthor_xml(path, file_movies, menu_entries, start_with_menu, play_all_opt)
 
         self.command_var=[]
         self.command_var.append("dvdauthor")
@@ -54,12 +54,12 @@ class dvdauthor_converter(devedeng.executor.executor):
 
 
     def process_stderr(self,data):
-        if (data != None) and (data[0] != ""):
+        if (data is not None) and (data[0] != ""):
             self.progress_bar[1].set_text(data[0])
         return
 
 
-    def create_dvdauthor_xml(self,movie_folder, file_movies, menu_entries, start_with_menu):
+    def create_dvdauthor_xml(self,movie_folder, file_movies, menu_entries, start_with_menu, play_all_opt):
 
         xmlpath = os.path.join(movie_folder,"xml_data")
         xml_file_path = os.path.join(xmlpath,"dvdauthor.xml")
@@ -69,12 +69,12 @@ class dvdauthor_converter(devedeng.executor.executor):
         except:
             pass
 
-        if (len(file_movies) == 1) and (menu_entries == None):
+        if (len(file_movies) == 1) and (menu_entries is None):
             onlyone = True
         else:
             onlyone = False
 
-        if (menu_entries == None):
+        if (menu_entries is None):
             elements_per_menu = 1000
         else:
             elements_per_menu = len(menu_entries[0]["chapters"])
@@ -83,7 +83,17 @@ class dvdauthor_converter(devedeng.executor.executor):
         xml_file.write('<dvdauthor dest="'+datapath+'">\n')
 
         if onlyone:
-            xml_file.write('\t<vmgm />\n')
+            xml_file.write('\t<vmgm>\n')
+            xml_file.write("\t\t<menus>\n")
+
+            xml_file.write('\t\t\t<video format="')
+            if self.config.PAL:
+                xml_file.write("pal")
+            else:
+                xml_file.write("ntsc")
+            xml_file.write('" aspect="4:3"> </video>\n')
+            xml_file.write("\t\t</menus>\n")
+            xml_file.write('\t</vmgm>\n')
         else:
             xml_file.write('\t<vmgm>\n')
 
@@ -94,11 +104,17 @@ class dvdauthor_converter(devedeng.executor.executor):
 
             xml_file.write('\t\t<fpc>\n')
             xml_file.write('\t\t\tg0=100;\n')
-            if (menu_entries != None) and (start_with_menu):
-                xml_file.write('\t\t\tg1=0;\n')
+            xml_file.write('\t\t\tg1=') #goto variable
+            if (menu_entries is not None) and (start_with_menu):
+                xml_file.write('0;\n') #show menu
             else:
-                xml_file.write('\t\t\tg1=100;\n')
-            xml_file.write('\t\t\tg2=1024;\n')
+                xml_file.write('100;\n') #auto play
+            xml_file.write('\t\t\tg2=1024;\n') #highlight?
+            xml_file.write('\t\t\tg3=') #play all variable
+            if play_all_opt and (menu_entries is not None) and (start_with_menu):
+                xml_file.write('1;\n') #auto play all
+            else:
+                xml_file.write('0;\n') #do not play all
             xml_file.write('\t\t\tjump menu 1;\n')
             xml_file.write('\t\t</fpc>\n')
 
@@ -167,14 +183,15 @@ class dvdauthor_converter(devedeng.executor.executor):
                     title_list.append(counter)
                 counter += 1
 
-            if (menu_entries != None):
+            if (menu_entries is not None):
                 nmenues = len(menu_entries)
-                button_counter = 0
+                title_counter = 0 # A counter for all titles
                 for menu_page in menu_entries:
+                    button_counter = 0 # A counter for all buttons on the actual page
                     xml_file.write('\t\t\t<pgc>\n')
                     xml_file.write('\t\t\t\t<pre>\n')
-                    # first we recover the currently selected button
-                    xml_file.write('\t\t\t\t\ts8=g2;\n')
+                    xml_file.write('\t\t\t\t\ts8=g2;\n') # first we recover the currently selected button
+                    xml_file.write('\t\t\t\t\tg3=0;\n') #turnoff play all
 
                     if first_entry: # here we add some code to jump to each menu
                         for menu2 in range(nmenues-1):
@@ -195,17 +212,29 @@ class dvdauthor_converter(devedeng.executor.executor):
                     xml_file.write('"></vob>\n')
 
                     for nbutton in menu_page["chapters"]:
-                        xml_file.write('\t\t\t\t<button name="'+nbutton+'"> g0='+str(title_list[button_counter])+'; jump vmgm menu; </button>\n')
+                        #xml_file.write('\t\t\t\t<button name="'+nbutton+'"> g0='+str(title_list[button_counter])+'; jump vmgm menu; </button>\n')
+                        xml_file.write('\t\t\t\t<button name="'+nbutton+'">\n')
+                        # If PlayAll option is set, the first button on each page
+                        # will be the PlayAll button
+                        if play_all_opt and button_counter==0:
+                            xml_file.write('\t\t\t\t\tg3=1;\n')
+                            xml_file.write('\t\t\t\t\tg0=1;\n')
+                            xml_file.write('\t\t\t\t\tjump vmgm menu;\n')
+                        else:
+                            xml_file.write('\t\t\t\t\tg0='+str(title_list[title_counter])+';\n')
+                            xml_file.write('\t\t\t\t\tjump vmgm menu;\n')
+                            title_counter+=1
                         button_counter+=1
+                        xml_file.write('\t\t\t\t</button>\n')
 
-                    if (menu_page["left"] != None):
+                    if (menu_page["left"] is not None):
                         xml_file.write('\t\t\t\t<button name="'+menu_page["left"]+'"> g1=')
                         xml_file.write(str(menu_number-1))
                         xml_file.write('; g2=1024; jump menu ')
                         xml_file.write(str(menu_number))
                         xml_file.write('; </button>\n')
 
-                    if (menu_page["right"] != None):
+                    if (menu_page["right"] is not None):
                         xml_file.write('\t\t\t\t<button name="'+menu_page["right"]+'"> g1=')
                         xml_file.write(str(menu_number+1))
                         xml_file.write('; g2=1024; jump menu ')
@@ -371,9 +400,19 @@ class dvdauthor_converter(devedeng.executor.executor):
             xml_file.write('chapters="0')
             if (element.original_length > 5):
                 if (element.divide_in_chapters): # add chapters
+                    manual_chapter_list = [];
+                    if (element.chapter_list_entry):
+                        manual_chapter_list = element.chapter_list_entry.split(",")
                     toadd = element.chapter_size
                     seconds = toadd*60
                     while seconds < (element.original_length - 4):
+                        # Check manual_chapter_list for manual entries before set next chapter
+                        for idx, m_chapter in enumerate(manual_chapter_list):
+                            m_chapter = m_chapter.split(":")
+                            m_chapter = int(m_chapter[0])*60+int(m_chapter[1]) # Change from mm:ss to seconds
+                            if (m_chapter < seconds):
+                                seconds = m_chapter
+                                del manual_chapter_list[idx]
                         thetime = self.return_time(seconds,False)
                         xml_file.write(","+thetime)
                         seconds += (toadd*60)
@@ -384,32 +423,42 @@ class dvdauthor_converter(devedeng.executor.executor):
                 xml_file.write('\t\t\t\t<post>\n')
                 files+=1
                 xml_file.write('\t\t\t\t\tg1='+str(int(titles/elements_per_menu))+';\n')
-                if (action=="action_stop"):
-                    xml_file.write('\t\t\t\t\tg0=100;\n')
-                    xml_file.write('\t\t\t\t\tcall vmgm menu entry title;\n')
-                else:
-                    xml_file.write('\t\t\t\t\tg0=')
-                    if action=="action_play_previous":
-                        if titles == 0:
-                            prev_t = total_t - 1
-                        else:
-                            prev_t = titles - 1
-                        xml_file.write(str(prev_t + 1))
-                    elif action=="action_play_again":
-                        xml_file.write(str(titles + 1))
-                    elif action=="action_play_next":
-                        if titles==total_t-1:
-                            next_t=0
-                        else:
-                            next_t=titles + 1
-                        xml_file.write(str(next_t + 1))
-                    elif action=="action_play_last":
-                        xml_file.write(str(total_t))
-                    else:
-                        xml_file.write('1') # first
 
-                    xml_file.write(';\n')
-                    xml_file.write('\t\t\t\t\tcall vmgm menu entry title;\n')
+                #play all
+                xml_file.write('\t\t\t\t\tif (g3 eq 1) {\n') #if play all:
+                if titles==total_t-1: #return to menu if last title
+                    xml_file.write('\t\t\t\t\t\tg0=100;\n')
+                else: #play next title
+                    xml_file.write('\t\t\t\t\t\tg0='+str(titles + 2)+';\n')
+                xml_file.write('\t\t\t\t\t} else {\n')
+
+                #end of play opt
+                xml_file.write('\t\t\t\t\t\tg0=')
+                if action=="action_stop":
+                    xml_file.write('100')
+                elif action=="action_play_previous":
+                    if titles == 0:
+                        prev_t = total_t - 1
+                    else:
+                        prev_t = titles - 1
+                    xml_file.write(str(prev_t + 1))
+                elif action=="action_play_again":
+                    xml_file.write(str(titles + 1))
+                elif action=="action_play_next":
+                    if titles==total_t-1:
+                        next_t=0
+                    else:
+                        next_t=titles + 1
+                    xml_file.write(str(next_t + 1))
+                elif action=="action_play_last":
+                    xml_file.write(str(total_t))
+                else:
+                    xml_file.write('1') # first
+
+                xml_file.write(';\n')
+                xml_file.write('\t\t\t\t\t}\n')
+
+                xml_file.write('\t\t\t\t\tcall vmgm menu entry title;\n') #preform action
                 xml_file.write('\t\t\t\t</post>\n')
             xml_file.write("\t\t\t</pgc>\n")
             xml_file.write("\t\t</titles>\n")
